async function readObjFile(path) {
	const res = await fetch(path);
	const text = await res.text();

	let vertices = [];
	let textures = [];
	let normals = [];

	let result = [];

	const lines = text.replace("\r","").split("\n");

	for (let line of lines) {
		const parts = line.split(/\s+/);
		
		switch (parts[0]) {
		case "v":
			vertices.push(parts.slice(1, 4).map(parseFloat));
			break;
		case "vt":
			textures.push(parts.slice(1, 3).map(parseFloat));
			break;
		case "vn":
			normals.push(parts.slice(1, 4).map(parseFloat));
			break;
		case "f":
			for (const part of parts.slice(1, 4)) {
				const [v, vt, vn] = part.split("/").map((i) => parseInt(i) - 1);
				result.push(...vertices[v], ...textures[vt], ...normals[vn]);
			}
			
			// support for quads:
			if (parts.length > 4) {
				for (let i of [1, 3, 4]) {
					const part = parts[i];
					const [v, vt, vn] = part.split("/").map((i) => parseInt(i) - 1);
					result.push(...vertices[v], ...textures[vt], ...normals[vn]);
				}
			}
		}
	}
	return result;
}